@@ -772,6 +772,261 @@ test_simde_vtbx4_u8 (SIMDE_MUNIT_TEST_ARGS) {
 #endif
 }
 
+static int
+test_simde_vtbx1_p8 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  struct {
+    SIMDE_ALIGN_TO_16 simde_poly8_t a[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t b[8];
+    SIMDE_ALIGN_TO_16 uint8_t c[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t r[8];
+  } test_vec[] = {
+    { { SIMDE_POLY8_C(109), SIMDE_POLY8_C(104), SIMDE_POLY8_C( 26), SIMDE_POLY8_C( 73), SIMDE_POLY8_C(176), SIMDE_POLY8_C(116), SIMDE_POLY8_C(156), SIMDE_POLY8_C(160) },
+      { SIMDE_POLY8_C(  0), SIMDE_POLY8_C(222), SIMDE_POLY8_C(196), SIMDE_POLY8_C( 35), SIMDE_POLY8_C(137), SIMDE_POLY8_C( 60), SIMDE_POLY8_C(133), SIMDE_POLY8_C( 75) },
+      { UINT8_C( 45), UINT8_C(  8), UINT8_C(117), UINT8_C( 15), UINT8_C(190), UINT8_C(119), UINT8_C(173), UINT8_C(217) },
+      { SIMDE_POLY8_C(109), SIMDE_POLY8_C(104), SIMDE_POLY8_C( 26), SIMDE_POLY8_C( 73), SIMDE_POLY8_C(176), SIMDE_POLY8_C(116), SIMDE_POLY8_C(156), SIMDE_POLY8_C(160) } },
+    { { SIMDE_POLY8_C(203), SIMDE_POLY8_C( 72), SIMDE_POLY8_C(220), SIMDE_POLY8_C(188), SIMDE_POLY8_C(199), SIMDE_POLY8_C( 12), SIMDE_POLY8_C(137), SIMDE_POLY8_C( 52) },
+      { SIMDE_POLY8_C(116), SIMDE_POLY8_C(163), SIMDE_POLY8_C(125), SIMDE_POLY8_C( 36), SIMDE_POLY8_C( 24), SIMDE_POLY8_C( 26), SIMDE_POLY8_C(197), SIMDE_POLY8_C( 24) },
+      { UINT8_C(248), UINT8_C(137), UINT8_C( 59), UINT8_C(129), UINT8_C(197), UINT8_C(192), UINT8_C(205), UINT8_C(242) },
+      { SIMDE_POLY8_C(203), SIMDE_POLY8_C( 72), SIMDE_POLY8_C(220), SIMDE_POLY8_C(188), SIMDE_POLY8_C(199), SIMDE_POLY8_C( 12), SIMDE_POLY8_C(137), SIMDE_POLY8_C( 52) } },
+    { { SIMDE_POLY8_C(200), SIMDE_POLY8_C( 66), SIMDE_POLY8_C(  2), SIMDE_POLY8_C(135), SIMDE_POLY8_C(185), SIMDE_POLY8_C(175), SIMDE_POLY8_C( 96), SIMDE_POLY8_C(132) },
+      { SIMDE_POLY8_C(247), SIMDE_POLY8_C( 61), SIMDE_POLY8_C( 64), SIMDE_POLY8_C(190), SIMDE_POLY8_C( 73), SIMDE_POLY8_C(201), SIMDE_POLY8_C(243), SIMDE_POLY8_C(190) },
+      { UINT8_C(109), UINT8_C(112), UINT8_C(226), UINT8_C(133), UINT8_C(138), UINT8_C(167), UINT8_C(157), UINT8_C(130) },
+      { SIMDE_POLY8_C(200), SIMDE_POLY8_C( 66), SIMDE_POLY8_C(  2), SIMDE_POLY8_C(135), SIMDE_POLY8_C(185), SIMDE_POLY8_C(175), SIMDE_POLY8_C( 96), SIMDE_POLY8_C(132) } },
+    { { SIMDE_POLY8_C( 48), SIMDE_POLY8_C(216), SIMDE_POLY8_C(  4), SIMDE_POLY8_C(245), SIMDE_POLY8_C(152), SIMDE_POLY8_C(209), SIMDE_POLY8_C(232), SIMDE_POLY8_C( 96) },
+      { SIMDE_POLY8_C( 19), SIMDE_POLY8_C(234), SIMDE_POLY8_C(231), SIMDE_POLY8_C(204), SIMDE_POLY8_C(153), SIMDE_POLY8_C( 72), SIMDE_POLY8_C( 80), SIMDE_POLY8_C(144) },
+      { UINT8_C(133), UINT8_C(144), UINT8_C( 78), UINT8_C(206), UINT8_C( 89), UINT8_C( 65), UINT8_C(140), UINT8_C(198) },
+      { SIMDE_POLY8_C( 48), SIMDE_POLY8_C(216), SIMDE_POLY8_C(  4), SIMDE_POLY8_C(245), SIMDE_POLY8_C(152), SIMDE_POLY8_C(209), SIMDE_POLY8_C(232), SIMDE_POLY8_C( 96) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde_poly8x8_t a = simde_vld1_p8(test_vec[i].a);
+    simde_poly8x8_t b = simde_vld1_p8(test_vec[i].b);
+    simde_uint8x8_t c = simde_vld1_u8(test_vec[i].c);
+    simde_poly8x8_t r = simde_vtbx1_p8(a, b, c);
+
+    simde_test_arm_neon_assert_equal_p8x8(r, simde_vld1_p8(test_vec[i].r));
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 4 ; i++) {
+    simde_poly8x8_t a = simde_test_arm_neon_random_p8x8();
+    simde_poly8x8_t b = simde_test_arm_neon_random_p8x8();
+    simde_uint8x8_t c = simde_test_arm_neon_random_u8x8();
+    simde_poly8x8_t r = simde_vtbx1_p8(a, b, c);
+
+    simde_test_arm_neon_write_p8x8(2, a, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_arm_neon_write_p8x8(2, b, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_u8x8(2, c, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_p8x8(2, r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
+static int
+test_simde_vtbx2_p8 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  struct {
+    SIMDE_ALIGN_TO_16 simde_poly8_t a[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t b[2][8];
+    SIMDE_ALIGN_TO_16 uint8_t c[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t r[8];
+  } test_vec[] = {
+     { { SIMDE_POLY8_C(178), SIMDE_POLY8_C(111), SIMDE_POLY8_C( 75), SIMDE_POLY8_C( 60), SIMDE_POLY8_C( 22), SIMDE_POLY8_C(232), SIMDE_POLY8_C(191), SIMDE_POLY8_C( 71) },
+        { { SIMDE_POLY8_C(192), SIMDE_POLY8_C(195), SIMDE_POLY8_C( 60), SIMDE_POLY8_C( 88), SIMDE_POLY8_C(148), SIMDE_POLY8_C( 36), SIMDE_POLY8_C(185), SIMDE_POLY8_C(167) },
+          { SIMDE_POLY8_C( 14), SIMDE_POLY8_C(160), SIMDE_POLY8_C(115), SIMDE_POLY8_C(167), SIMDE_POLY8_C(232), SIMDE_POLY8_C(195), SIMDE_POLY8_C( 55), SIMDE_POLY8_C(109) } },
+      { UINT8_C( 83), UINT8_C(134), UINT8_C( 60), UINT8_C(172), UINT8_C(199), UINT8_C(200), UINT8_C(115), UINT8_C(121) },
+      { SIMDE_POLY8_C(178), SIMDE_POLY8_C(111), SIMDE_POLY8_C( 75), SIMDE_POLY8_C( 60), SIMDE_POLY8_C( 22), SIMDE_POLY8_C(232), SIMDE_POLY8_C(191), SIMDE_POLY8_C( 71) } },
+    { { SIMDE_POLY8_C( 55), SIMDE_POLY8_C(190), SIMDE_POLY8_C(182), SIMDE_POLY8_C( 78), SIMDE_POLY8_C(167), SIMDE_POLY8_C(117), SIMDE_POLY8_C(149), SIMDE_POLY8_C(103) },
+        { { SIMDE_POLY8_C( 56), SIMDE_POLY8_C(209), SIMDE_POLY8_C(192), SIMDE_POLY8_C(204), SIMDE_POLY8_C(246), SIMDE_POLY8_C(121), SIMDE_POLY8_C(115), SIMDE_POLY8_C(  4) },
+          { SIMDE_POLY8_C( 25), SIMDE_POLY8_C(230), SIMDE_POLY8_C(172), SIMDE_POLY8_C(  2), SIMDE_POLY8_C(169), SIMDE_POLY8_C(227), SIMDE_POLY8_C(111), SIMDE_POLY8_C(252) } },
+      { UINT8_C(105), UINT8_C(171), UINT8_C(168), UINT8_C( 49), UINT8_C(116), UINT8_C( 27), UINT8_C(170), UINT8_C(171) },
+      { SIMDE_POLY8_C( 55), SIMDE_POLY8_C(190), SIMDE_POLY8_C(182), SIMDE_POLY8_C( 78), SIMDE_POLY8_C(167), SIMDE_POLY8_C(117), SIMDE_POLY8_C(149), SIMDE_POLY8_C(103) } },
+    { { SIMDE_POLY8_C(218), SIMDE_POLY8_C( 96), SIMDE_POLY8_C(249), SIMDE_POLY8_C(129), SIMDE_POLY8_C(213), SIMDE_POLY8_C(142), SIMDE_POLY8_C(232), SIMDE_POLY8_C( 13) },
+        { { SIMDE_POLY8_C( 96), SIMDE_POLY8_C(168), SIMDE_POLY8_C(217), SIMDE_POLY8_C( 86), SIMDE_POLY8_C( 33), SIMDE_POLY8_C( 76), SIMDE_POLY8_C( 90), SIMDE_POLY8_C( 59) },
+          { SIMDE_POLY8_C( 50), SIMDE_POLY8_C(  6), SIMDE_POLY8_C( 61), SIMDE_POLY8_C(219), SIMDE_POLY8_C(234), SIMDE_POLY8_C(172), SIMDE_POLY8_C(215), SIMDE_POLY8_C( 83) } },
+      { UINT8_C( 88), UINT8_C(128), UINT8_C(132), UINT8_C(204), UINT8_C(155), UINT8_C( 47), UINT8_C(119), UINT8_C(117) },
+      { SIMDE_POLY8_C(218), SIMDE_POLY8_C( 96), SIMDE_POLY8_C(249), SIMDE_POLY8_C(129), SIMDE_POLY8_C(213), SIMDE_POLY8_C(142), SIMDE_POLY8_C(232), SIMDE_POLY8_C( 13) } },
+    { { SIMDE_POLY8_C(143), SIMDE_POLY8_C(113), SIMDE_POLY8_C(246), SIMDE_POLY8_C(101),    SIMDE_POLY8_C(UINT8_MAX), SIMDE_POLY8_C(223), SIMDE_POLY8_C(114), SIMDE_POLY8_C( 95) },
+        { { SIMDE_POLY8_C(135), SIMDE_POLY8_C( 76), SIMDE_POLY8_C(181), SIMDE_POLY8_C(169), SIMDE_POLY8_C(152), SIMDE_POLY8_C( 16), SIMDE_POLY8_C(228), SIMDE_POLY8_C(203) },
+          { SIMDE_POLY8_C( 22), SIMDE_POLY8_C( 33), SIMDE_POLY8_C(166), SIMDE_POLY8_C(  0), SIMDE_POLY8_C(205), SIMDE_POLY8_C(126), SIMDE_POLY8_C( 84), SIMDE_POLY8_C( 37) } },
+      { UINT8_C(254), UINT8_C(216), UINT8_C(241), UINT8_C(153), UINT8_C(  7), UINT8_C(105), UINT8_C( 15), UINT8_C(151) },
+      { SIMDE_POLY8_C(143), SIMDE_POLY8_C(113), SIMDE_POLY8_C(246), SIMDE_POLY8_C(101), SIMDE_POLY8_C(203), SIMDE_POLY8_C(223), SIMDE_POLY8_C( 37), SIMDE_POLY8_C( 95) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde_poly8x8_t a, r;
+    simde_uint8x8_t c;
+    simde_poly8x8x2_t b;
+    a = simde_vld1_p8(test_vec[i].a);
+    b.val[0]  = simde_vld1_p8(test_vec[i].b[0]);
+    b.val[1]  = simde_vld1_p8(test_vec[i].b[1]);
+    c = simde_vld1_u8(test_vec[i].c);
+    r = simde_vtbx2_p8(a, b, c);
+
+    simde_test_arm_neon_assert_equal_p8x8(r, simde_vld1_p8(test_vec[i].r));
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 4 ; i++) {
+    simde_poly8x8_t a = simde_test_arm_neon_random_p8x8();
+    simde_poly8x8x2_t b = simde_test_arm_neon_random_p8x8x2();
+    simde_uint8x8_t c = simde_test_arm_neon_random_u8x8();
+    simde_poly8x8_t r = simde_vtbx2_p8(a, b, c);
+
+    simde_test_arm_neon_write_p8x8(2, a, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_arm_neon_write_p8x8x2(2, b, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_u8x8(2, c, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_p8x8(2, r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
+static int
+test_simde_vtbx3_p8 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  struct {
+    SIMDE_ALIGN_TO_16 simde_poly8_t a[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t b[3][8];
+    SIMDE_ALIGN_TO_16 uint8_t c[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t r[8];
+  } test_vec[] = {
+    { { SIMDE_POLY8_C(198), SIMDE_POLY8_C(228), SIMDE_POLY8_C(140), SIMDE_POLY8_C(104), SIMDE_POLY8_C( 25), SIMDE_POLY8_C(115), SIMDE_POLY8_C(130), SIMDE_POLY8_C(173) },
+        { { SIMDE_POLY8_C( 17), SIMDE_POLY8_C(185), SIMDE_POLY8_C(153), SIMDE_POLY8_C(254), SIMDE_POLY8_C( 58), SIMDE_POLY8_C( 10), SIMDE_POLY8_C(117), SIMDE_POLY8_C( 25) },
+          { SIMDE_POLY8_C(240), SIMDE_POLY8_C( 23), SIMDE_POLY8_C(132), SIMDE_POLY8_C(212), SIMDE_POLY8_C(167), SIMDE_POLY8_C(189), SIMDE_POLY8_C( 90), SIMDE_POLY8_C(168) },
+          { SIMDE_POLY8_C( 35), SIMDE_POLY8_C(252), SIMDE_POLY8_C(197), SIMDE_POLY8_C( 85), SIMDE_POLY8_C( 90), SIMDE_POLY8_C( 92), SIMDE_POLY8_C(129), SIMDE_POLY8_C( 32) } },
+      { UINT8_C( 64), UINT8_C( 13), UINT8_C(137), UINT8_C( 89), UINT8_C(129), UINT8_C( 11), UINT8_C(  7), UINT8_C(146) },
+      { SIMDE_POLY8_C(198), SIMDE_POLY8_C(189), SIMDE_POLY8_C(140), SIMDE_POLY8_C(104), SIMDE_POLY8_C( 25), SIMDE_POLY8_C(212), SIMDE_POLY8_C( 25), SIMDE_POLY8_C(173) } },
+    { { SIMDE_POLY8_C(196), SIMDE_POLY8_C(160), SIMDE_POLY8_C(144), SIMDE_POLY8_C(254), SIMDE_POLY8_C(170), SIMDE_POLY8_C(  5), SIMDE_POLY8_C( 23), SIMDE_POLY8_C(155) },
+        { { SIMDE_POLY8_C( 28), SIMDE_POLY8_C(156), SIMDE_POLY8_C(111), SIMDE_POLY8_C(195), SIMDE_POLY8_C( 89), SIMDE_POLY8_C(202), SIMDE_POLY8_C(107), SIMDE_POLY8_C(125) },
+          { SIMDE_POLY8_C(198), SIMDE_POLY8_C( 48), SIMDE_POLY8_C(210), SIMDE_POLY8_C( 32), SIMDE_POLY8_C(140), SIMDE_POLY8_C( 83), SIMDE_POLY8_C( 65), SIMDE_POLY8_C(204) },
+          { SIMDE_POLY8_C( 97), SIMDE_POLY8_C(202), SIMDE_POLY8_C( 38), SIMDE_POLY8_C(226), SIMDE_POLY8_C(213), SIMDE_POLY8_C( 45), SIMDE_POLY8_C(116), SIMDE_POLY8_C(153) } },
+      { UINT8_C(205), UINT8_C(  4), UINT8_C(151), UINT8_C(119), UINT8_C(  9), UINT8_C(174), UINT8_C( 18), UINT8_C( 37) },
+      { SIMDE_POLY8_C(196), SIMDE_POLY8_C( 89), SIMDE_POLY8_C(144), SIMDE_POLY8_C(254), SIMDE_POLY8_C( 48), SIMDE_POLY8_C(  5), SIMDE_POLY8_C( 38), SIMDE_POLY8_C(155) } },
+    { { SIMDE_POLY8_C( 74), SIMDE_POLY8_C(130), SIMDE_POLY8_C(233), SIMDE_POLY8_C(164), SIMDE_POLY8_C( 76), SIMDE_POLY8_C( 84), SIMDE_POLY8_C( 33), SIMDE_POLY8_C( 18) },
+        { { SIMDE_POLY8_C(133), SIMDE_POLY8_C(243), SIMDE_POLY8_C( 50), SIMDE_POLY8_C( 17), SIMDE_POLY8_C( 70), SIMDE_POLY8_C(115), SIMDE_POLY8_C(222), SIMDE_POLY8_C(167) },
+          { SIMDE_POLY8_C( 61), SIMDE_POLY8_C(  4), SIMDE_POLY8_C(137), SIMDE_POLY8_C( 18), SIMDE_POLY8_C( 49), SIMDE_POLY8_C(253), SIMDE_POLY8_C(171), SIMDE_POLY8_C(254) },
+          { SIMDE_POLY8_C(  1), SIMDE_POLY8_C( 66), SIMDE_POLY8_C(117), SIMDE_POLY8_C( 10), SIMDE_POLY8_C(241), SIMDE_POLY8_C(136), SIMDE_POLY8_C( 48), SIMDE_POLY8_C( 59) } },
+      { UINT8_C( 10), UINT8_C( 25), UINT8_C(223), UINT8_C( 86), UINT8_C(109), UINT8_C(  0), UINT8_C(104), UINT8_C(242) },
+      { SIMDE_POLY8_C(137), SIMDE_POLY8_C(130), SIMDE_POLY8_C(233), SIMDE_POLY8_C(164), SIMDE_POLY8_C( 76), SIMDE_POLY8_C(133), SIMDE_POLY8_C( 33), SIMDE_POLY8_C( 18) } },
+    { { SIMDE_POLY8_C(243), SIMDE_POLY8_C(154), SIMDE_POLY8_C(  4), SIMDE_POLY8_C( 58), SIMDE_POLY8_C( 14), SIMDE_POLY8_C(226), SIMDE_POLY8_C(225), SIMDE_POLY8_C( 75) },
+        { { SIMDE_POLY8_C(230), SIMDE_POLY8_C(107), SIMDE_POLY8_C( 94), SIMDE_POLY8_C( 23), SIMDE_POLY8_C(104), SIMDE_POLY8_C(  9), SIMDE_POLY8_C( 21), SIMDE_POLY8_C(106) },
+          { SIMDE_POLY8_C( 76), SIMDE_POLY8_C(138), SIMDE_POLY8_C(116), SIMDE_POLY8_C( 61), SIMDE_POLY8_C( 18), SIMDE_POLY8_C(164), SIMDE_POLY8_C(120), SIMDE_POLY8_C( 28) },
+          { SIMDE_POLY8_C(189), SIMDE_POLY8_C( 88), SIMDE_POLY8_C(114), SIMDE_POLY8_C( 43), SIMDE_POLY8_C( 88), SIMDE_POLY8_C(218), SIMDE_POLY8_C( 29), SIMDE_POLY8_C( 76) } },
+      { UINT8_C(117), UINT8_C( 33), UINT8_C(134), UINT8_C(131), UINT8_C(  3), UINT8_C(103), UINT8_C(206), UINT8_C(233) },
+      { SIMDE_POLY8_C(243), SIMDE_POLY8_C(154), SIMDE_POLY8_C(  4), SIMDE_POLY8_C( 58), SIMDE_POLY8_C( 23), SIMDE_POLY8_C(226), SIMDE_POLY8_C(225), SIMDE_POLY8_C( 75) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde_poly8x8_t a, r;
+    simde_uint8x8_t c;
+    simde_poly8x8x3_t b;
+    a = simde_vld1_p8(test_vec[i].a);
+    b.val[0]  = simde_vld1_p8(test_vec[i].b[0]);
+    b.val[1]  = simde_vld1_p8(test_vec[i].b[1]);
+    b.val[2]  = simde_vld1_p8(test_vec[i].b[2]);
+    c = simde_vld1_u8(test_vec[i].c);
+    r = simde_vtbx3_p8(a, b, c);
+
+    simde_test_arm_neon_assert_equal_p8x8(r, simde_vld1_p8(test_vec[i].r));
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 4 ; i++) {
+    simde_poly8x8_t a = simde_test_arm_neon_random_p8x8();
+    simde_poly8x8x3_t b = simde_test_arm_neon_random_p8x8x3();
+    simde_uint8x8_t c = simde_test_arm_neon_random_u8x8();
+    simde_poly8x8_t r = simde_vtbx3_p8(a, b, c);
+
+    simde_test_arm_neon_write_p8x8(2, a, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_arm_neon_write_p8x8x3(2, b, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_u8x8(2, c, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_p8x8(2, r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
+static int
+test_simde_vtbx4_p8 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  struct {
+    SIMDE_ALIGN_TO_16 simde_poly8_t a[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t b[4][8];
+    SIMDE_ALIGN_TO_16 uint8_t c[8];
+    SIMDE_ALIGN_TO_16 simde_poly8_t r[8];
+  } test_vec[] = {
+    { { SIMDE_POLY8_C(210), SIMDE_POLY8_C( 44), SIMDE_POLY8_C(  0), SIMDE_POLY8_C( 59), SIMDE_POLY8_C( 54), SIMDE_POLY8_C( 21), SIMDE_POLY8_C(165), SIMDE_POLY8_C(130) },
+        { { SIMDE_POLY8_C(160), SIMDE_POLY8_C( 25), SIMDE_POLY8_C(191), SIMDE_POLY8_C(178), SIMDE_POLY8_C(190), SIMDE_POLY8_C( 55), SIMDE_POLY8_C(207), SIMDE_POLY8_C(123) },
+          { SIMDE_POLY8_C(143), SIMDE_POLY8_C( 65), SIMDE_POLY8_C(166), SIMDE_POLY8_C(232), SIMDE_POLY8_C( 28), SIMDE_POLY8_C(196), SIMDE_POLY8_C( 52), SIMDE_POLY8_C(145) },
+          { SIMDE_POLY8_C(229), SIMDE_POLY8_C(186), SIMDE_POLY8_C( 20), SIMDE_POLY8_C(233), SIMDE_POLY8_C( 33), SIMDE_POLY8_C(226), SIMDE_POLY8_C(210), SIMDE_POLY8_C(244) },
+          { SIMDE_POLY8_C( 15), SIMDE_POLY8_C(211), SIMDE_POLY8_C( 47), SIMDE_POLY8_C( 69), SIMDE_POLY8_C(232), SIMDE_POLY8_C(212), SIMDE_POLY8_C(199), SIMDE_POLY8_C(136) } },
+      { UINT8_C(237), UINT8_C(134), UINT8_C( 59), UINT8_C(171), UINT8_C(189), UINT8_C( 10), UINT8_C( 39), UINT8_C( 77) },
+      { SIMDE_POLY8_C(210), SIMDE_POLY8_C( 44), SIMDE_POLY8_C(  0), SIMDE_POLY8_C( 59), SIMDE_POLY8_C( 54), SIMDE_POLY8_C(166), SIMDE_POLY8_C(165), SIMDE_POLY8_C(130) } },
+    { { SIMDE_POLY8_C( 75), SIMDE_POLY8_C(205), SIMDE_POLY8_C( 53), SIMDE_POLY8_C(103), SIMDE_POLY8_C(145), SIMDE_POLY8_C(105), SIMDE_POLY8_C(248), SIMDE_POLY8_C(119) },
+        { { SIMDE_POLY8_C( 35), SIMDE_POLY8_C( 12), SIMDE_POLY8_C( 96), SIMDE_POLY8_C( 68), SIMDE_POLY8_C(239), SIMDE_POLY8_C( 50), SIMDE_POLY8_C( 56), SIMDE_POLY8_C(254) },
+          { SIMDE_POLY8_C(  5), SIMDE_POLY8_C(103), SIMDE_POLY8_C( 67), SIMDE_POLY8_C(238), SIMDE_POLY8_C( 59), SIMDE_POLY8_C( 10), SIMDE_POLY8_C(118), SIMDE_POLY8_C( 41) },
+          { SIMDE_POLY8_C(144), SIMDE_POLY8_C(177), SIMDE_POLY8_C(212), SIMDE_POLY8_C( 77), SIMDE_POLY8_C(187), SIMDE_POLY8_C(251), SIMDE_POLY8_C(154), SIMDE_POLY8_C(  7) },
+          { SIMDE_POLY8_C(201), SIMDE_POLY8_C(207), SIMDE_POLY8_C(110), SIMDE_POLY8_C( 90), SIMDE_POLY8_C( 56), SIMDE_POLY8_C(103), SIMDE_POLY8_C(209), SIMDE_POLY8_C( 91) } },
+      { UINT8_C(115), UINT8_C( 49), UINT8_C(160), UINT8_C( 98), UINT8_C(100), UINT8_C(216), UINT8_C( 96), UINT8_C(105) },
+      { SIMDE_POLY8_C( 75), SIMDE_POLY8_C(205), SIMDE_POLY8_C( 53), SIMDE_POLY8_C(103), SIMDE_POLY8_C(145), SIMDE_POLY8_C(105), SIMDE_POLY8_C(248), SIMDE_POLY8_C(119) } },
+    { { SIMDE_POLY8_C( 64), SIMDE_POLY8_C(163), SIMDE_POLY8_C( 87), SIMDE_POLY8_C(123), SIMDE_POLY8_C(173), SIMDE_POLY8_C(206), SIMDE_POLY8_C(164), SIMDE_POLY8_C( 61) },
+        { { SIMDE_POLY8_C(127), SIMDE_POLY8_C(121), SIMDE_POLY8_C(139), SIMDE_POLY8_C( 59), SIMDE_POLY8_C(116), SIMDE_POLY8_C( 37), SIMDE_POLY8_C( 66), SIMDE_POLY8_C( 61) },
+          { SIMDE_POLY8_C(245), SIMDE_POLY8_C(176), SIMDE_POLY8_C(152), SIMDE_POLY8_C( 45), SIMDE_POLY8_C( 23), SIMDE_POLY8_C(105), SIMDE_POLY8_C(137), SIMDE_POLY8_C(139) },
+          { SIMDE_POLY8_C(155), SIMDE_POLY8_C( 41), SIMDE_POLY8_C(237),    SIMDE_POLY8_C(UINT8_MAX), SIMDE_POLY8_C(  1), SIMDE_POLY8_C( 78), SIMDE_POLY8_C(104), SIMDE_POLY8_C( 65) },
+          { SIMDE_POLY8_C(241), SIMDE_POLY8_C(192), SIMDE_POLY8_C(189), SIMDE_POLY8_C(159), SIMDE_POLY8_C(142), SIMDE_POLY8_C( 97), SIMDE_POLY8_C(220), SIMDE_POLY8_C( 13) } },
+      { UINT8_C(218), UINT8_C(103), UINT8_C( 72), UINT8_C( 79), UINT8_C(141), UINT8_C(138), UINT8_C(140), UINT8_C(130) },
+      { SIMDE_POLY8_C( 64), SIMDE_POLY8_C(163), SIMDE_POLY8_C( 87), SIMDE_POLY8_C(123), SIMDE_POLY8_C(173), SIMDE_POLY8_C(206), SIMDE_POLY8_C(164), SIMDE_POLY8_C( 61) } },
+    { { SIMDE_POLY8_C( 59), SIMDE_POLY8_C( 36), SIMDE_POLY8_C(175), SIMDE_POLY8_C( 82), SIMDE_POLY8_C(142), SIMDE_POLY8_C( 56), SIMDE_POLY8_C(221), SIMDE_POLY8_C( 41) },
+        { { SIMDE_POLY8_C( 97), SIMDE_POLY8_C(203), SIMDE_POLY8_C( 40), SIMDE_POLY8_C( 99), SIMDE_POLY8_C( 25), SIMDE_POLY8_C(144), SIMDE_POLY8_C(164), SIMDE_POLY8_C( 10) },
+          { SIMDE_POLY8_C( 80), SIMDE_POLY8_C( 97), SIMDE_POLY8_C(169), SIMDE_POLY8_C(222), SIMDE_POLY8_C(195), SIMDE_POLY8_C(134), SIMDE_POLY8_C(236), SIMDE_POLY8_C(157) },
+          { SIMDE_POLY8_C(237), SIMDE_POLY8_C( 52), SIMDE_POLY8_C(236), SIMDE_POLY8_C(122), SIMDE_POLY8_C(191), SIMDE_POLY8_C(121), SIMDE_POLY8_C(252), SIMDE_POLY8_C(250) },
+          { SIMDE_POLY8_C(157), SIMDE_POLY8_C(172), SIMDE_POLY8_C( 76), SIMDE_POLY8_C( 43), SIMDE_POLY8_C(228), SIMDE_POLY8_C( 42), SIMDE_POLY8_C( 84), SIMDE_POLY8_C( 70) } },
+      { UINT8_C(245), UINT8_C(124), UINT8_C(169), UINT8_C( 14), UINT8_C( 13), UINT8_C( 77), UINT8_C( 24), UINT8_C( 93) },
+      { SIMDE_POLY8_C( 59), SIMDE_POLY8_C( 36), SIMDE_POLY8_C(175), SIMDE_POLY8_C(236), SIMDE_POLY8_C(134), SIMDE_POLY8_C( 56), SIMDE_POLY8_C(157), SIMDE_POLY8_C( 41) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde_poly8x8_t a, r;
+    simde_uint8x8_t c;
+    simde_poly8x8x4_t b;
+    a = simde_vld1_p8(test_vec[i].a);
+    b.val[0]  = simde_vld1_p8(test_vec[i].b[0]);
+    b.val[1]  = simde_vld1_p8(test_vec[i].b[1]);
+    b.val[2]  = simde_vld1_p8(test_vec[i].b[2]);
+    b.val[3]  = simde_vld1_p8(test_vec[i].b[3]);
+    c = simde_vld1_u8(test_vec[i].c);
+    r = simde_vtbx4_p8(a, b, c);
+
+    simde_test_arm_neon_assert_equal_p8x8(r, simde_vld1_p8(test_vec[i].r));
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 4 ; i++) {
+    simde_poly8x8_t a = simde_test_arm_neon_random_p8x8();
+    simde_poly8x8x4_t b = simde_test_arm_neon_random_p8x8x4();
+    simde_uint8x8_t c = simde_test_arm_neon_random_u8x8();
+    simde_poly8x8_t r = simde_vtbx4_p8(a, b, c);
+
+    simde_test_arm_neon_write_p8x8(2, a, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_arm_neon_write_p8x8x4(2, b, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_u8x8(2, c, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_arm_neon_write_p8x8(2, r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
 #endif /* !defined(SIMDE_BUG_INTEL_857088) */
 
 SIMDE_TEST_FUNC_LIST_BEGIN
@@ -784,6 +1039,11 @@ SIMDE_TEST_FUNC_LIST_ENTRY(vtbx1_u8)
   SIMDE_TEST_FUNC_LIST_ENTRY(vtbx3_u8)
   SIMDE_TEST_FUNC_LIST_ENTRY(vtbx4_s8)
   SIMDE_TEST_FUNC_LIST_ENTRY(vtbx4_u8)
+
+  SIMDE_TEST_FUNC_LIST_ENTRY(vtbx1_p8)
+  SIMDE_TEST_FUNC_LIST_ENTRY(vtbx2_p8)
+  SIMDE_TEST_FUNC_LIST_ENTRY(vtbx3_p8)
+  SIMDE_TEST_FUNC_LIST_ENTRY(vtbx4_p8)
 #endif /* !defined(SIMDE_BUG_INTEL_857088) */
 SIMDE_TEST_FUNC_LIST_END
 
