@@ -461,6 +461,154 @@ test_simde_mm512_mask_storeu_epi16 (SIMDE_MUNIT_TEST_ARGS) {
 #endif
 }
 
+static int
+test_simde_mm512_mask_storeu_epi32 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  static const struct {
+    const simde__mmask16 k;
+    const int32_t a[16];
+    const int32_t r[16];
+  } test_vec[] = {
+    { UINT16_C(55402),
+      { -INT32_C(   482117629),  INT32_C(  1751154497),  INT32_C(   358358359), -INT32_C(  1089895882), -INT32_C(  2112504547), -INT32_C(   136177260),  INT32_C(   730405331), -INT32_C(  1929120887),
+        -INT32_C(  1401928085),  INT32_C(   487903429),  INT32_C(   607285741),  INT32_C(   283327475), -INT32_C(  1919747848), -INT32_C(   444304366),  INT32_C(   370150797),  INT32_C(  1805849344) },
+      {  INT32_C(           0),  INT32_C(  1751154497),  INT32_C(           0), -INT32_C(  1089895882),  INT32_C(           0), -INT32_C(   136177260),  INT32_C(   730405331),  INT32_C(           0),
+         INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(   283327475), -INT32_C(  1919747848),  INT32_C(           0),  INT32_C(   370150797),  INT32_C(  1805849344) } },
+    { UINT16_C( 4953),
+      {  INT32_C(   753147415),  INT32_C(  1839059259), -INT32_C(   659975947),  INT32_C(   852599200), -INT32_C(  1297685714), -INT32_C(   658558008), -INT32_C(   303317175),  INT32_C(  1107313706),
+        -INT32_C(  1636899742), -INT32_C(  1425339466),  INT32_C(   998552731), -INT32_C(  2073209514),  INT32_C(     3609400), -INT32_C(  1881606586), -INT32_C(   528694346),  INT32_C(  1763867911) },
+      {  INT32_C(   753147415),  INT32_C(           0),  INT32_C(           0),  INT32_C(   852599200), -INT32_C(  1297685714),  INT32_C(           0), -INT32_C(   303317175),  INT32_C(           0),
+        -INT32_C(  1636899742), -INT32_C(  1425339466),  INT32_C(           0),  INT32_C(           0),  INT32_C(     3609400),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0) } },
+    { UINT16_C(36961),
+      {  INT32_C(   328931079),  INT32_C(  1204238019), -INT32_C(   560194191), -INT32_C(   638462814), -INT32_C(  1395705900),  INT32_C(  1131382215), -INT32_C(  2000652698), -INT32_C(   417783073),
+        -INT32_C(    50678727),  INT32_C(  1547944427), -INT32_C(  2126782497), -INT32_C(  2024133453),  INT32_C(   724773220),  INT32_C(   359572143), -INT32_C(   123916520), -INT32_C(  1965050287) },
+      {  INT32_C(   328931079),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(  1131382215), -INT32_C(  2000652698),  INT32_C(           0),
+         INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(   724773220),  INT32_C(           0),  INT32_C(           0), -INT32_C(  1965050287) } },
+    { UINT16_C(55659),
+      { -INT32_C(   895854969), -INT32_C(   307594830),  INT32_C(  1411014138),  INT32_C(   410943205),  INT32_C(   398142889), -INT32_C(   549006526), -INT32_C(  1432971317), -INT32_C(  1451032286),
+         INT32_C(   158539351), -INT32_C(  1829298793),  INT32_C(  1625690491),  INT32_C(   947414159), -INT32_C(   749784175), -INT32_C(   759982585),  INT32_C(  1333610797), -INT32_C(  1577582518) },
+      { -INT32_C(   895854969), -INT32_C(   307594830),  INT32_C(           0),  INT32_C(   410943205),  INT32_C(           0), -INT32_C(   549006526), -INT32_C(  1432971317),  INT32_C(           0),
+         INT32_C(   158539351),  INT32_C(           0),  INT32_C(           0),  INT32_C(   947414159), -INT32_C(   749784175),  INT32_C(           0),  INT32_C(  1333610797), -INT32_C(  1577582518) } },
+    { UINT16_C(27678),
+      { -INT32_C(  1584810326),  INT32_C(   783418440), -INT32_C(   577552028), -INT32_C(   921688967), -INT32_C(  1419831304),  INT32_C(  1744080106), -INT32_C(   731431204), -INT32_C(  1992259873),
+        -INT32_C(  2077504964),  INT32_C(   867360206), -INT32_C(  1743764193),  INT32_C(  1650532458),  INT32_C(   571326520),  INT32_C(   696844621),  INT32_C(   519958591), -INT32_C(  1297662346) },
+      {  INT32_C(           0),  INT32_C(   783418440), -INT32_C(   577552028), -INT32_C(   921688967), -INT32_C(  1419831304),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),
+         INT32_C(           0),  INT32_C(           0), -INT32_C(  1743764193),  INT32_C(  1650532458),  INT32_C(           0),  INT32_C(   696844621),  INT32_C(   519958591),  INT32_C(           0) } },
+    { UINT16_C(53768),
+      { -INT32_C(   374286794),  INT32_C(   422498057), -INT32_C(   918906777),  INT32_C(   126448378),  INT32_C(   487118484), -INT32_C(    49461249),  INT32_C(   222004325),  INT32_C(  1843348278),
+         INT32_C(   592875289), -INT32_C(   969112482),  INT32_C(   395277853),  INT32_C(  2082412776), -INT32_C(   291952657), -INT32_C(   722753681),  INT32_C(  1642145323), -INT32_C(  2083602071) },
+      {  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(   126448378),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),
+         INT32_C(           0), -INT32_C(   969112482),  INT32_C(           0),  INT32_C(           0), -INT32_C(   291952657),  INT32_C(           0),  INT32_C(  1642145323), -INT32_C(  2083602071) } },
+    { UINT16_C( 9296),
+      { -INT32_C(   492195930),  INT32_C(    72992373), -INT32_C(    65256995),  INT32_C(  1461980094), -INT32_C(   436300806),  INT32_C(  1225533799),  INT32_C(  1493857675), -INT32_C(  1635886344),
+         INT32_C(  2122393353), -INT32_C(   897393939), -INT32_C(   641229029), -INT32_C(  1540232278), -INT32_C(   443928706), -INT32_C(   466708903),  INT32_C(    71120907), -INT32_C(  1667056749) },
+      {  INT32_C(           0),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0), -INT32_C(   436300806),  INT32_C(           0),  INT32_C(  1493857675),  INT32_C(           0),
+         INT32_C(           0),  INT32_C(           0), -INT32_C(   641229029),  INT32_C(           0),  INT32_C(           0), -INT32_C(   466708903),  INT32_C(           0),  INT32_C(           0) } },
+    { UINT16_C( 9186),
+      { -INT32_C(  1644310757),  INT32_C(  1631328666),  INT32_C(   592242674),  INT32_C(   357812875), -INT32_C(   559174481), -INT32_C(   854149232),  INT32_C(  1569302971),  INT32_C(  1635871558),
+        -INT32_C(   704741829), -INT32_C(  1976157289), -INT32_C(  1381137886), -INT32_C(    71106484),  INT32_C(  1020882604), -INT32_C(   536154075), -INT32_C(   549547111),  INT32_C(   960544766) },
+      {  INT32_C(           0),  INT32_C(  1631328666),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0), -INT32_C(   854149232),  INT32_C(  1569302971),  INT32_C(  1635871558),
+        -INT32_C(   704741829), -INT32_C(  1976157289),  INT32_C(           0),  INT32_C(           0),  INT32_C(           0), -INT32_C(   536154075),  INT32_C(           0),  INT32_C(           0) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde__m512i a = simde_mm512_loadu_epi32(test_vec[i].a);
+    int32_t r[sizeof(simde__m512i) / sizeof(int32_t)] = {0};
+    simde_mm512_mask_storeu_epi32(r, test_vec[i].k, a);
+    simde_assert_equal_vi32(sizeof(r) / sizeof(r[0]), r, test_vec[i].r);
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 8 ; i++) {
+    simde__mmask16 k = simde_test_x86_random_mmask16();
+    simde__m512i a = simde_test_x86_random_i32x16();
+    int32_t r[sizeof(simde__m512i) / sizeof(int32_t)] = {0};
+    simde_mm512_mask_storeu_epi32(r, k, a);
+
+    simde_test_x86_write_mmask16(2, k, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_x86_write_i32x16(2, a, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_codegen_write_vi32(2, sizeof(r) / sizeof(r[0]), r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
+static int
+test_simde_mm512_mask_storeu_epi64 (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  static const struct {
+    const simde__mmask8 k;
+    const int64_t a[8];
+    const int64_t r[8];
+  } test_vec[] = {
+    { UINT8_C(140),
+      {  INT64_C( 2562700009037383963),  INT64_C( 1308779348439673865), -INT64_C( 5339793039729417525),  INT64_C( 2117810040372576678),
+        -INT64_C( 8756891595817225406),  INT64_C( 1830653111813772914),  INT64_C( 2244642510274902763), -INT64_C( 8470329406450741421) },
+      {  INT64_C(                   0),  INT64_C(                   0), -INT64_C( 5339793039729417525),  INT64_C( 2117810040372576678),
+         INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0), -INT64_C( 8470329406450741421) } },
+    { UINT8_C( 75),
+      { -INT64_C( 1089783859999285208), -INT64_C( 2980442202066504465), -INT64_C( 8508586972572412923), -INT64_C( 2592001133508411293),
+         INT64_C( 1046851753557545021),  INT64_C( 2508621669439293022), -INT64_C( 1206501201345372546), -INT64_C( 5947652635700358171) },
+      { -INT64_C( 1089783859999285208), -INT64_C( 2980442202066504465),  INT64_C(                   0), -INT64_C( 2592001133508411293),
+         INT64_C(                   0),  INT64_C(                   0), -INT64_C( 1206501201345372546),  INT64_C(                   0) } },
+    { UINT8_C(129),
+      { -INT64_C( 7978214924530662209),  INT64_C( 3485453036345573750),  INT64_C( 7716543402514060939), -INT64_C( 2051239941935222955),
+         INT64_C( 5704112228317014476),  INT64_C( 3861429489220180053),  INT64_C( 6009345608553681571), -INT64_C( 7768178532301520854) },
+      { -INT64_C( 7978214924530662209),  INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0),
+         INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0), -INT64_C( 7768178532301520854) } },
+    { UINT8_C( 12),
+      {  INT64_C( 3271359719308340477), -INT64_C( 5362930207397852061),  INT64_C( 3681418865116679537), -INT64_C( 7760106128574487200),
+        -INT64_C( 3873646092186471492), -INT64_C( 7930754142963100200),  INT64_C(  648964377864479707),  INT64_C( 5343127945035447802) },
+      {  INT64_C(                   0),  INT64_C(                   0),  INT64_C( 3681418865116679537), -INT64_C( 7760106128574487200),
+         INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0) } },
+    { UINT8_C(206),
+      { -INT64_C( 5787406331112235829),  INT64_C( 9143259257570912954), -INT64_C( 5733309158096653857), -INT64_C(  944198849684176771),
+        -INT64_C( 3085396635198874652),  INT64_C( 4592194289628216930), -INT64_C( 8010739272058084751),  INT64_C( 9168358635236430371) },
+      {  INT64_C(                   0),  INT64_C( 9143259257570912954), -INT64_C( 5733309158096653857), -INT64_C(  944198849684176771),
+         INT64_C(                   0),  INT64_C(                   0), -INT64_C( 8010739272058084751),  INT64_C( 9168358635236430371) } },
+    { UINT8_C(168),
+      {  INT64_C( 3161412780293357061), -INT64_C( 5140635953256522890), -INT64_C( 5564941019078996866),  INT64_C( 5780312172140433154),
+         INT64_C(  657996772073667273), -INT64_C(  768453664766448441),  INT64_C( 9080764808903925939), -INT64_C( 1799956482170727830) },
+      {  INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0),  INT64_C( 5780312172140433154),
+         INT64_C(                   0), -INT64_C(  768453664766448441),  INT64_C(                   0), -INT64_C( 1799956482170727830) } },
+    { UINT8_C( 63),
+      { -INT64_C( 6177007952796131886),  INT64_C( 6464377649729954587),  INT64_C( 7021766093045041580), -INT64_C(    7488577646745760),
+        -INT64_C( 5842641429838514366), -INT64_C( 3730557049928414297), -INT64_C( 4404443046703001744),  INT64_C(  475778217440468589) },
+      { -INT64_C( 6177007952796131886),  INT64_C( 6464377649729954587),  INT64_C( 7021766093045041580), -INT64_C(    7488577646745760),
+        -INT64_C( 5842641429838514366), -INT64_C( 3730557049928414297),  INT64_C(                   0),  INT64_C(                   0) } },
+    { UINT8_C(  4),
+      {  INT64_C( 4360404944681387800), -INT64_C( 5923313649767848714), -INT64_C( 8452745041858835459), -INT64_C(  176954415573480647),
+         INT64_C( 6776049819067163291), -INT64_C( 8283096560490092863),  INT64_C( 2776613124672920530), -INT64_C( 4129740201756141875) },
+      {  INT64_C(                   0),  INT64_C(                   0), -INT64_C( 8452745041858835459),  INT64_C(                   0),
+         INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0),  INT64_C(                   0) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde__m512i a = simde_mm512_loadu_epi64(test_vec[i].a);
+    int64_t r[sizeof(simde__m512i) / sizeof(int64_t)] = {0};
+    simde_mm512_mask_storeu_epi64(r, test_vec[i].k, a);
+    simde_assert_equal_vi64(sizeof(r) / sizeof(r[0]), r, test_vec[i].r);
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 8 ; i++) {
+    simde__mmask8 k = simde_test_x86_random_mmask8();
+    simde__m512i a = simde_test_x86_random_i64x8();
+    int64_t r[sizeof(simde__m512i) / sizeof(int64_t)] = {0};
+    simde_mm512_mask_storeu_epi64(r, k, a);
+
+    simde_test_x86_write_mmask8(2, k, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_x86_write_i64x8(2, a, SIMDE_TEST_VEC_POS_MIDDLE);
+    simde_test_codegen_write_vi64(2, sizeof(r) / sizeof(r[0]), r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+
 static int
 test_simde_mm512_storeu_ps (SIMDE_MUNIT_TEST_ARGS) {
 #if 1
@@ -556,6 +704,167 @@ test_simde_mm512_storeu_ps (SIMDE_MUNIT_TEST_ARGS) {
 #endif
 }
 
+#if defined(SIMDE_FLOAT16_IS_SCALAR)
+static int
+test_simde_mm512_storeu_ph (SIMDE_MUNIT_TEST_ARGS) {
+#if 1
+  static const struct {
+    const simde_float16 a[32];
+    const simde_float16 r[32];
+  } test_vec[] = {
+    { { SIMDE_FLOAT16_VALUE(   614.50), SIMDE_FLOAT16_VALUE(   397.50), SIMDE_FLOAT16_VALUE(   743.00), SIMDE_FLOAT16_VALUE(   963.00),
+        SIMDE_FLOAT16_VALUE(   996.00), SIMDE_FLOAT16_VALUE(  -396.25), SIMDE_FLOAT16_VALUE(   558.50), SIMDE_FLOAT16_VALUE(  -368.25),
+        SIMDE_FLOAT16_VALUE(   209.25), SIMDE_FLOAT16_VALUE(   440.00), SIMDE_FLOAT16_VALUE(  -763.50), SIMDE_FLOAT16_VALUE(   731.00),
+        SIMDE_FLOAT16_VALUE(  -291.50), SIMDE_FLOAT16_VALUE(  -477.50), SIMDE_FLOAT16_VALUE(   439.25), SIMDE_FLOAT16_VALUE(  -934.50),
+        SIMDE_FLOAT16_VALUE(   999.50), SIMDE_FLOAT16_VALUE(  -494.75), SIMDE_FLOAT16_VALUE(    79.06), SIMDE_FLOAT16_VALUE(   249.88),
+        SIMDE_FLOAT16_VALUE(  -358.00), SIMDE_FLOAT16_VALUE(   242.00), SIMDE_FLOAT16_VALUE(  -751.50), SIMDE_FLOAT16_VALUE(   483.25),
+        SIMDE_FLOAT16_VALUE(  -873.00), SIMDE_FLOAT16_VALUE(   974.50), SIMDE_FLOAT16_VALUE(  -845.50), SIMDE_FLOAT16_VALUE(   801.00),
+        SIMDE_FLOAT16_VALUE(  -563.50), SIMDE_FLOAT16_VALUE(    43.72), SIMDE_FLOAT16_VALUE(  -969.50), SIMDE_FLOAT16_VALUE(  -949.00) },
+      { SIMDE_FLOAT16_VALUE(   614.50), SIMDE_FLOAT16_VALUE(   397.50), SIMDE_FLOAT16_VALUE(   743.00), SIMDE_FLOAT16_VALUE(   963.00),
+        SIMDE_FLOAT16_VALUE(   996.00), SIMDE_FLOAT16_VALUE(  -396.25), SIMDE_FLOAT16_VALUE(   558.50), SIMDE_FLOAT16_VALUE(  -368.25),
+        SIMDE_FLOAT16_VALUE(   209.25), SIMDE_FLOAT16_VALUE(   440.00), SIMDE_FLOAT16_VALUE(  -763.50), SIMDE_FLOAT16_VALUE(   731.00),
+        SIMDE_FLOAT16_VALUE(  -291.50), SIMDE_FLOAT16_VALUE(  -477.50), SIMDE_FLOAT16_VALUE(   439.25), SIMDE_FLOAT16_VALUE(  -934.50),
+        SIMDE_FLOAT16_VALUE(   999.50), SIMDE_FLOAT16_VALUE(  -494.75), SIMDE_FLOAT16_VALUE(    79.06), SIMDE_FLOAT16_VALUE(   249.88),
+        SIMDE_FLOAT16_VALUE(  -358.00), SIMDE_FLOAT16_VALUE(   242.00), SIMDE_FLOAT16_VALUE(  -751.50), SIMDE_FLOAT16_VALUE(   483.25),
+        SIMDE_FLOAT16_VALUE(  -873.00), SIMDE_FLOAT16_VALUE(   974.50), SIMDE_FLOAT16_VALUE(  -845.50), SIMDE_FLOAT16_VALUE(   801.00),
+        SIMDE_FLOAT16_VALUE(  -563.50), SIMDE_FLOAT16_VALUE(    43.72), SIMDE_FLOAT16_VALUE(  -969.50), SIMDE_FLOAT16_VALUE(  -949.00) } },
+    { { SIMDE_FLOAT16_VALUE(  -559.00), SIMDE_FLOAT16_VALUE(   773.50), SIMDE_FLOAT16_VALUE(  -985.50), SIMDE_FLOAT16_VALUE(  -562.50),
+        SIMDE_FLOAT16_VALUE(  -622.50), SIMDE_FLOAT16_VALUE(   572.50), SIMDE_FLOAT16_VALUE(    69.19), SIMDE_FLOAT16_VALUE(   586.50),
+        SIMDE_FLOAT16_VALUE(    12.58), SIMDE_FLOAT16_VALUE(   305.75), SIMDE_FLOAT16_VALUE(   317.75), SIMDE_FLOAT16_VALUE(   721.00),
+        SIMDE_FLOAT16_VALUE(   828.50), SIMDE_FLOAT16_VALUE(  -243.00), SIMDE_FLOAT16_VALUE(   786.50), SIMDE_FLOAT16_VALUE(   828.00),
+        SIMDE_FLOAT16_VALUE(   262.25), SIMDE_FLOAT16_VALUE(  -134.50), SIMDE_FLOAT16_VALUE(    77.88), SIMDE_FLOAT16_VALUE(   904.00),
+        SIMDE_FLOAT16_VALUE(  -892.50), SIMDE_FLOAT16_VALUE(   326.00), SIMDE_FLOAT16_VALUE(   387.50), SIMDE_FLOAT16_VALUE(  -765.50),
+        SIMDE_FLOAT16_VALUE(   300.50), SIMDE_FLOAT16_VALUE(   542.00), SIMDE_FLOAT16_VALUE(  -965.00), SIMDE_FLOAT16_VALUE(   737.00),
+        SIMDE_FLOAT16_VALUE(  -414.00), SIMDE_FLOAT16_VALUE(  -934.50), SIMDE_FLOAT16_VALUE(   788.00), SIMDE_FLOAT16_VALUE(    27.16) },
+      { SIMDE_FLOAT16_VALUE(  -559.00), SIMDE_FLOAT16_VALUE(   773.50), SIMDE_FLOAT16_VALUE(  -985.50), SIMDE_FLOAT16_VALUE(  -562.50),
+        SIMDE_FLOAT16_VALUE(  -622.50), SIMDE_FLOAT16_VALUE(   572.50), SIMDE_FLOAT16_VALUE(    69.19), SIMDE_FLOAT16_VALUE(   586.50),
+        SIMDE_FLOAT16_VALUE(    12.58), SIMDE_FLOAT16_VALUE(   305.75), SIMDE_FLOAT16_VALUE(   317.75), SIMDE_FLOAT16_VALUE(   721.00),
+        SIMDE_FLOAT16_VALUE(   828.50), SIMDE_FLOAT16_VALUE(  -243.00), SIMDE_FLOAT16_VALUE(   786.50), SIMDE_FLOAT16_VALUE(   828.00),
+        SIMDE_FLOAT16_VALUE(   262.25), SIMDE_FLOAT16_VALUE(  -134.50), SIMDE_FLOAT16_VALUE(    77.88), SIMDE_FLOAT16_VALUE(   904.00),
+        SIMDE_FLOAT16_VALUE(  -892.50), SIMDE_FLOAT16_VALUE(   326.00), SIMDE_FLOAT16_VALUE(   387.50), SIMDE_FLOAT16_VALUE(  -765.50),
+        SIMDE_FLOAT16_VALUE(   300.50), SIMDE_FLOAT16_VALUE(   542.00), SIMDE_FLOAT16_VALUE(  -965.00), SIMDE_FLOAT16_VALUE(   737.00),
+        SIMDE_FLOAT16_VALUE(  -414.00), SIMDE_FLOAT16_VALUE(  -934.50), SIMDE_FLOAT16_VALUE(   788.00), SIMDE_FLOAT16_VALUE(    27.16) } },
+    { { SIMDE_FLOAT16_VALUE(   839.00), SIMDE_FLOAT16_VALUE(   802.50), SIMDE_FLOAT16_VALUE(   464.50), SIMDE_FLOAT16_VALUE(  -783.50),
+        SIMDE_FLOAT16_VALUE(   375.00), SIMDE_FLOAT16_VALUE(  -466.25), SIMDE_FLOAT16_VALUE(   803.00), SIMDE_FLOAT16_VALUE(  -612.50),
+        SIMDE_FLOAT16_VALUE(   839.50), SIMDE_FLOAT16_VALUE(   120.81), SIMDE_FLOAT16_VALUE(  -891.00), SIMDE_FLOAT16_VALUE(   668.00),
+        SIMDE_FLOAT16_VALUE(   878.00), SIMDE_FLOAT16_VALUE(   895.00), SIMDE_FLOAT16_VALUE(   495.75), SIMDE_FLOAT16_VALUE(   140.00),
+        SIMDE_FLOAT16_VALUE(  -239.25), SIMDE_FLOAT16_VALUE(  -426.50), SIMDE_FLOAT16_VALUE(    44.31), SIMDE_FLOAT16_VALUE(  -131.75),
+        SIMDE_FLOAT16_VALUE(   899.50), SIMDE_FLOAT16_VALUE(  -568.00), SIMDE_FLOAT16_VALUE(   102.56), SIMDE_FLOAT16_VALUE(   200.00),
+        SIMDE_FLOAT16_VALUE(   974.00), SIMDE_FLOAT16_VALUE(   137.75), SIMDE_FLOAT16_VALUE(   -62.97), SIMDE_FLOAT16_VALUE(  -440.00),
+        SIMDE_FLOAT16_VALUE(   203.38), SIMDE_FLOAT16_VALUE(  -275.00), SIMDE_FLOAT16_VALUE(   587.00), SIMDE_FLOAT16_VALUE(    42.59) },
+      { SIMDE_FLOAT16_VALUE(   839.00), SIMDE_FLOAT16_VALUE(   802.50), SIMDE_FLOAT16_VALUE(   464.50), SIMDE_FLOAT16_VALUE(  -783.50),
+        SIMDE_FLOAT16_VALUE(   375.00), SIMDE_FLOAT16_VALUE(  -466.25), SIMDE_FLOAT16_VALUE(   803.00), SIMDE_FLOAT16_VALUE(  -612.50),
+        SIMDE_FLOAT16_VALUE(   839.50), SIMDE_FLOAT16_VALUE(   120.81), SIMDE_FLOAT16_VALUE(  -891.00), SIMDE_FLOAT16_VALUE(   668.00),
+        SIMDE_FLOAT16_VALUE(   878.00), SIMDE_FLOAT16_VALUE(   895.00), SIMDE_FLOAT16_VALUE(   495.75), SIMDE_FLOAT16_VALUE(   140.00),
+        SIMDE_FLOAT16_VALUE(  -239.25), SIMDE_FLOAT16_VALUE(  -426.50), SIMDE_FLOAT16_VALUE(    44.31), SIMDE_FLOAT16_VALUE(  -131.75),
+        SIMDE_FLOAT16_VALUE(   899.50), SIMDE_FLOAT16_VALUE(  -568.00), SIMDE_FLOAT16_VALUE(   102.56), SIMDE_FLOAT16_VALUE(   200.00),
+        SIMDE_FLOAT16_VALUE(   974.00), SIMDE_FLOAT16_VALUE(   137.75), SIMDE_FLOAT16_VALUE(   -62.97), SIMDE_FLOAT16_VALUE(  -440.00),
+        SIMDE_FLOAT16_VALUE(   203.38), SIMDE_FLOAT16_VALUE(  -275.00), SIMDE_FLOAT16_VALUE(   587.00), SIMDE_FLOAT16_VALUE(    42.59) } },
+    { { SIMDE_FLOAT16_VALUE(  -472.50), SIMDE_FLOAT16_VALUE(    51.56), SIMDE_FLOAT16_VALUE(   259.00), SIMDE_FLOAT16_VALUE(   902.50),
+        SIMDE_FLOAT16_VALUE(   585.00), SIMDE_FLOAT16_VALUE(    62.31), SIMDE_FLOAT16_VALUE(  -710.00), SIMDE_FLOAT16_VALUE(   424.75),
+        SIMDE_FLOAT16_VALUE(  -817.00), SIMDE_FLOAT16_VALUE(  -601.00), SIMDE_FLOAT16_VALUE(    92.44), SIMDE_FLOAT16_VALUE(  -939.00),
+        SIMDE_FLOAT16_VALUE(  -706.00), SIMDE_FLOAT16_VALUE(  -411.75), SIMDE_FLOAT16_VALUE(   200.88), SIMDE_FLOAT16_VALUE(    54.81),
+        SIMDE_FLOAT16_VALUE(   161.75), SIMDE_FLOAT16_VALUE(  -755.00), SIMDE_FLOAT16_VALUE(   923.00), SIMDE_FLOAT16_VALUE(    61.38),
+        SIMDE_FLOAT16_VALUE(  -323.00), SIMDE_FLOAT16_VALUE(    25.62), SIMDE_FLOAT16_VALUE(  -738.50), SIMDE_FLOAT16_VALUE(  -349.00),
+        SIMDE_FLOAT16_VALUE(  -836.50), SIMDE_FLOAT16_VALUE(   198.50), SIMDE_FLOAT16_VALUE(   211.00), SIMDE_FLOAT16_VALUE(   366.75),
+        SIMDE_FLOAT16_VALUE(   923.50), SIMDE_FLOAT16_VALUE(  -201.88), SIMDE_FLOAT16_VALUE(  -590.50), SIMDE_FLOAT16_VALUE(  -549.00) },
+      { SIMDE_FLOAT16_VALUE(  -472.50), SIMDE_FLOAT16_VALUE(    51.56), SIMDE_FLOAT16_VALUE(   259.00), SIMDE_FLOAT16_VALUE(   902.50),
+        SIMDE_FLOAT16_VALUE(   585.00), SIMDE_FLOAT16_VALUE(    62.31), SIMDE_FLOAT16_VALUE(  -710.00), SIMDE_FLOAT16_VALUE(   424.75),
+        SIMDE_FLOAT16_VALUE(  -817.00), SIMDE_FLOAT16_VALUE(  -601.00), SIMDE_FLOAT16_VALUE(    92.44), SIMDE_FLOAT16_VALUE(  -939.00),
+        SIMDE_FLOAT16_VALUE(  -706.00), SIMDE_FLOAT16_VALUE(  -411.75), SIMDE_FLOAT16_VALUE(   200.88), SIMDE_FLOAT16_VALUE(    54.81),
+        SIMDE_FLOAT16_VALUE(   161.75), SIMDE_FLOAT16_VALUE(  -755.00), SIMDE_FLOAT16_VALUE(   923.00), SIMDE_FLOAT16_VALUE(    61.38),
+        SIMDE_FLOAT16_VALUE(  -323.00), SIMDE_FLOAT16_VALUE(    25.62), SIMDE_FLOAT16_VALUE(  -738.50), SIMDE_FLOAT16_VALUE(  -349.00),
+        SIMDE_FLOAT16_VALUE(  -836.50), SIMDE_FLOAT16_VALUE(   198.50), SIMDE_FLOAT16_VALUE(   211.00), SIMDE_FLOAT16_VALUE(   366.75),
+        SIMDE_FLOAT16_VALUE(   923.50), SIMDE_FLOAT16_VALUE(  -201.88), SIMDE_FLOAT16_VALUE(  -590.50), SIMDE_FLOAT16_VALUE(  -549.00) } },
+    { { SIMDE_FLOAT16_VALUE(   849.50), SIMDE_FLOAT16_VALUE(   668.50), SIMDE_FLOAT16_VALUE(  -646.50), SIMDE_FLOAT16_VALUE(   435.00),
+        SIMDE_FLOAT16_VALUE(  -269.25), SIMDE_FLOAT16_VALUE(  -356.25), SIMDE_FLOAT16_VALUE(  -140.38), SIMDE_FLOAT16_VALUE(   -86.06),
+        SIMDE_FLOAT16_VALUE(    42.69), SIMDE_FLOAT16_VALUE(   952.00), SIMDE_FLOAT16_VALUE(   -25.16), SIMDE_FLOAT16_VALUE(   336.75),
+        SIMDE_FLOAT16_VALUE(  -459.75), SIMDE_FLOAT16_VALUE(  -824.00), SIMDE_FLOAT16_VALUE(  -608.50), SIMDE_FLOAT16_VALUE(   702.00),
+        SIMDE_FLOAT16_VALUE(  -579.00), SIMDE_FLOAT16_VALUE(  -685.50), SIMDE_FLOAT16_VALUE(  -236.75), SIMDE_FLOAT16_VALUE(    98.06),
+        SIMDE_FLOAT16_VALUE(   340.25), SIMDE_FLOAT16_VALUE(    24.69), SIMDE_FLOAT16_VALUE(   749.00), SIMDE_FLOAT16_VALUE(   503.75),
+        SIMDE_FLOAT16_VALUE(  -777.00), SIMDE_FLOAT16_VALUE(   -39.78), SIMDE_FLOAT16_VALUE(  -129.50), SIMDE_FLOAT16_VALUE(  -853.00),
+        SIMDE_FLOAT16_VALUE(   758.50), SIMDE_FLOAT16_VALUE(   280.00), SIMDE_FLOAT16_VALUE(  -402.25), SIMDE_FLOAT16_VALUE(   608.00) },
+      { SIMDE_FLOAT16_VALUE(   849.50), SIMDE_FLOAT16_VALUE(   668.50), SIMDE_FLOAT16_VALUE(  -646.50), SIMDE_FLOAT16_VALUE(   435.00),
+        SIMDE_FLOAT16_VALUE(  -269.25), SIMDE_FLOAT16_VALUE(  -356.25), SIMDE_FLOAT16_VALUE(  -140.38), SIMDE_FLOAT16_VALUE(   -86.06),
+        SIMDE_FLOAT16_VALUE(    42.69), SIMDE_FLOAT16_VALUE(   952.00), SIMDE_FLOAT16_VALUE(   -25.16), SIMDE_FLOAT16_VALUE(   336.75),
+        SIMDE_FLOAT16_VALUE(  -459.75), SIMDE_FLOAT16_VALUE(  -824.00), SIMDE_FLOAT16_VALUE(  -608.50), SIMDE_FLOAT16_VALUE(   702.00),
+        SIMDE_FLOAT16_VALUE(  -579.00), SIMDE_FLOAT16_VALUE(  -685.50), SIMDE_FLOAT16_VALUE(  -236.75), SIMDE_FLOAT16_VALUE(    98.06),
+        SIMDE_FLOAT16_VALUE(   340.25), SIMDE_FLOAT16_VALUE(    24.69), SIMDE_FLOAT16_VALUE(   749.00), SIMDE_FLOAT16_VALUE(   503.75),
+        SIMDE_FLOAT16_VALUE(  -777.00), SIMDE_FLOAT16_VALUE(   -39.78), SIMDE_FLOAT16_VALUE(  -129.50), SIMDE_FLOAT16_VALUE(  -853.00),
+        SIMDE_FLOAT16_VALUE(   758.50), SIMDE_FLOAT16_VALUE(   280.00), SIMDE_FLOAT16_VALUE(  -402.25), SIMDE_FLOAT16_VALUE(   608.00) } },
+    { { SIMDE_FLOAT16_VALUE(   -51.50), SIMDE_FLOAT16_VALUE(   -48.50), SIMDE_FLOAT16_VALUE(    42.84), SIMDE_FLOAT16_VALUE(   679.50),
+        SIMDE_FLOAT16_VALUE(   595.50), SIMDE_FLOAT16_VALUE(   902.50), SIMDE_FLOAT16_VALUE(  -406.75), SIMDE_FLOAT16_VALUE(  -362.00),
+        SIMDE_FLOAT16_VALUE(   854.50), SIMDE_FLOAT16_VALUE(   568.00), SIMDE_FLOAT16_VALUE(   975.00), SIMDE_FLOAT16_VALUE(  -605.50),
+        SIMDE_FLOAT16_VALUE(   744.00), SIMDE_FLOAT16_VALUE(  -633.50), SIMDE_FLOAT16_VALUE(  -903.50), SIMDE_FLOAT16_VALUE(  -835.00),
+        SIMDE_FLOAT16_VALUE(  -319.00), SIMDE_FLOAT16_VALUE(  -140.25), SIMDE_FLOAT16_VALUE(   263.00), SIMDE_FLOAT16_VALUE(  -979.00),
+        SIMDE_FLOAT16_VALUE(   884.50), SIMDE_FLOAT16_VALUE(    12.23), SIMDE_FLOAT16_VALUE(   525.00), SIMDE_FLOAT16_VALUE(  -892.50),
+        SIMDE_FLOAT16_VALUE(   972.50), SIMDE_FLOAT16_VALUE(  -604.50), SIMDE_FLOAT16_VALUE(  -745.50), SIMDE_FLOAT16_VALUE(   731.00),
+        SIMDE_FLOAT16_VALUE(   675.50), SIMDE_FLOAT16_VALUE(  -147.75), SIMDE_FLOAT16_VALUE(   338.75), SIMDE_FLOAT16_VALUE(  -376.00) },
+      { SIMDE_FLOAT16_VALUE(   -51.50), SIMDE_FLOAT16_VALUE(   -48.50), SIMDE_FLOAT16_VALUE(    42.84), SIMDE_FLOAT16_VALUE(   679.50),
+        SIMDE_FLOAT16_VALUE(   595.50), SIMDE_FLOAT16_VALUE(   902.50), SIMDE_FLOAT16_VALUE(  -406.75), SIMDE_FLOAT16_VALUE(  -362.00),
+        SIMDE_FLOAT16_VALUE(   854.50), SIMDE_FLOAT16_VALUE(   568.00), SIMDE_FLOAT16_VALUE(   975.00), SIMDE_FLOAT16_VALUE(  -605.50),
+        SIMDE_FLOAT16_VALUE(   744.00), SIMDE_FLOAT16_VALUE(  -633.50), SIMDE_FLOAT16_VALUE(  -903.50), SIMDE_FLOAT16_VALUE(  -835.00),
+        SIMDE_FLOAT16_VALUE(  -319.00), SIMDE_FLOAT16_VALUE(  -140.25), SIMDE_FLOAT16_VALUE(   263.00), SIMDE_FLOAT16_VALUE(  -979.00),
+        SIMDE_FLOAT16_VALUE(   884.50), SIMDE_FLOAT16_VALUE(    12.23), SIMDE_FLOAT16_VALUE(   525.00), SIMDE_FLOAT16_VALUE(  -892.50),
+        SIMDE_FLOAT16_VALUE(   972.50), SIMDE_FLOAT16_VALUE(  -604.50), SIMDE_FLOAT16_VALUE(  -745.50), SIMDE_FLOAT16_VALUE(   731.00),
+        SIMDE_FLOAT16_VALUE(   675.50), SIMDE_FLOAT16_VALUE(  -147.75), SIMDE_FLOAT16_VALUE(   338.75), SIMDE_FLOAT16_VALUE(  -376.00) } },
+    { { SIMDE_FLOAT16_VALUE(   803.50), SIMDE_FLOAT16_VALUE(  -618.50), SIMDE_FLOAT16_VALUE(  -697.00), SIMDE_FLOAT16_VALUE(   399.00),
+        SIMDE_FLOAT16_VALUE(  -716.00), SIMDE_FLOAT16_VALUE(  -103.50), SIMDE_FLOAT16_VALUE(  -963.00), SIMDE_FLOAT16_VALUE(  -861.50),
+        SIMDE_FLOAT16_VALUE(  -535.50), SIMDE_FLOAT16_VALUE(  -988.50), SIMDE_FLOAT16_VALUE(  -467.00), SIMDE_FLOAT16_VALUE(  -791.50),
+        SIMDE_FLOAT16_VALUE(  -622.00), SIMDE_FLOAT16_VALUE(  -370.50), SIMDE_FLOAT16_VALUE(  -626.50), SIMDE_FLOAT16_VALUE(    59.03),
+        SIMDE_FLOAT16_VALUE(   489.25), SIMDE_FLOAT16_VALUE(   636.50), SIMDE_FLOAT16_VALUE(    80.25), SIMDE_FLOAT16_VALUE(   373.75),
+        SIMDE_FLOAT16_VALUE(  -351.25), SIMDE_FLOAT16_VALUE(  -394.75), SIMDE_FLOAT16_VALUE(   481.25), SIMDE_FLOAT16_VALUE(  -378.75),
+        SIMDE_FLOAT16_VALUE(     0.61), SIMDE_FLOAT16_VALUE(   735.50), SIMDE_FLOAT16_VALUE(  -648.00), SIMDE_FLOAT16_VALUE(  -324.00),
+        SIMDE_FLOAT16_VALUE(  -412.25), SIMDE_FLOAT16_VALUE(   690.50), SIMDE_FLOAT16_VALUE(   299.75), SIMDE_FLOAT16_VALUE(  -608.50) },
+      { SIMDE_FLOAT16_VALUE(   803.50), SIMDE_FLOAT16_VALUE(  -618.50), SIMDE_FLOAT16_VALUE(  -697.00), SIMDE_FLOAT16_VALUE(   399.00),
+        SIMDE_FLOAT16_VALUE(  -716.00), SIMDE_FLOAT16_VALUE(  -103.50), SIMDE_FLOAT16_VALUE(  -963.00), SIMDE_FLOAT16_VALUE(  -861.50),
+        SIMDE_FLOAT16_VALUE(  -535.50), SIMDE_FLOAT16_VALUE(  -988.50), SIMDE_FLOAT16_VALUE(  -467.00), SIMDE_FLOAT16_VALUE(  -791.50),
+        SIMDE_FLOAT16_VALUE(  -622.00), SIMDE_FLOAT16_VALUE(  -370.50), SIMDE_FLOAT16_VALUE(  -626.50), SIMDE_FLOAT16_VALUE(    59.03),
+        SIMDE_FLOAT16_VALUE(   489.25), SIMDE_FLOAT16_VALUE(   636.50), SIMDE_FLOAT16_VALUE(    80.25), SIMDE_FLOAT16_VALUE(   373.75),
+        SIMDE_FLOAT16_VALUE(  -351.25), SIMDE_FLOAT16_VALUE(  -394.75), SIMDE_FLOAT16_VALUE(   481.25), SIMDE_FLOAT16_VALUE(  -378.75),
+        SIMDE_FLOAT16_VALUE(     0.61), SIMDE_FLOAT16_VALUE(   735.50), SIMDE_FLOAT16_VALUE(  -648.00), SIMDE_FLOAT16_VALUE(  -324.00),
+        SIMDE_FLOAT16_VALUE(  -412.25), SIMDE_FLOAT16_VALUE(   690.50), SIMDE_FLOAT16_VALUE(   299.75), SIMDE_FLOAT16_VALUE(  -608.50) } },
+    { { SIMDE_FLOAT16_VALUE(  -927.50), SIMDE_FLOAT16_VALUE(   603.00), SIMDE_FLOAT16_VALUE(   790.50), SIMDE_FLOAT16_VALUE(  -644.00),
+        SIMDE_FLOAT16_VALUE(  -500.50), SIMDE_FLOAT16_VALUE(   827.50), SIMDE_FLOAT16_VALUE(  -505.25), SIMDE_FLOAT16_VALUE(   -35.69),
+        SIMDE_FLOAT16_VALUE(   839.00), SIMDE_FLOAT16_VALUE(    27.69), SIMDE_FLOAT16_VALUE(   172.88), SIMDE_FLOAT16_VALUE(  -783.00),
+        SIMDE_FLOAT16_VALUE(   657.00), SIMDE_FLOAT16_VALUE(   546.50), SIMDE_FLOAT16_VALUE(   276.25), SIMDE_FLOAT16_VALUE(   146.50),
+        SIMDE_FLOAT16_VALUE(   183.00), SIMDE_FLOAT16_VALUE(  -643.50), SIMDE_FLOAT16_VALUE(  -479.75), SIMDE_FLOAT16_VALUE(   832.00),
+        SIMDE_FLOAT16_VALUE(   -38.28), SIMDE_FLOAT16_VALUE(  -998.50), SIMDE_FLOAT16_VALUE(  -547.00), SIMDE_FLOAT16_VALUE(   962.50),
+        SIMDE_FLOAT16_VALUE(   737.00), SIMDE_FLOAT16_VALUE(  -194.88), SIMDE_FLOAT16_VALUE(  -361.75), SIMDE_FLOAT16_VALUE(  -675.00),
+        SIMDE_FLOAT16_VALUE(  -504.00), SIMDE_FLOAT16_VALUE(   938.00), SIMDE_FLOAT16_VALUE(  -283.50), SIMDE_FLOAT16_VALUE(  -431.75) },
+      { SIMDE_FLOAT16_VALUE(  -927.50), SIMDE_FLOAT16_VALUE(   603.00), SIMDE_FLOAT16_VALUE(   790.50), SIMDE_FLOAT16_VALUE(  -644.00),
+        SIMDE_FLOAT16_VALUE(  -500.50), SIMDE_FLOAT16_VALUE(   827.50), SIMDE_FLOAT16_VALUE(  -505.25), SIMDE_FLOAT16_VALUE(   -35.69),
+        SIMDE_FLOAT16_VALUE(   839.00), SIMDE_FLOAT16_VALUE(    27.69), SIMDE_FLOAT16_VALUE(   172.88), SIMDE_FLOAT16_VALUE(  -783.00),
+        SIMDE_FLOAT16_VALUE(   657.00), SIMDE_FLOAT16_VALUE(   546.50), SIMDE_FLOAT16_VALUE(   276.25), SIMDE_FLOAT16_VALUE(   146.50),
+        SIMDE_FLOAT16_VALUE(   183.00), SIMDE_FLOAT16_VALUE(  -643.50), SIMDE_FLOAT16_VALUE(  -479.75), SIMDE_FLOAT16_VALUE(   832.00),
+        SIMDE_FLOAT16_VALUE(   -38.28), SIMDE_FLOAT16_VALUE(  -998.50), SIMDE_FLOAT16_VALUE(  -547.00), SIMDE_FLOAT16_VALUE(   962.50),
+        SIMDE_FLOAT16_VALUE(   737.00), SIMDE_FLOAT16_VALUE(  -194.88), SIMDE_FLOAT16_VALUE(  -361.75), SIMDE_FLOAT16_VALUE(  -675.00),
+        SIMDE_FLOAT16_VALUE(  -504.00), SIMDE_FLOAT16_VALUE(   938.00), SIMDE_FLOAT16_VALUE(  -283.50), SIMDE_FLOAT16_VALUE(  -431.75) } },
+  };
+
+  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
+    simde__m512h a = simde_mm512_loadu_ph(test_vec[i].a);
+    simde_float16 r[sizeof(simde__m512) / sizeof(simde_float16)] = { SIMDE_FLOAT16_VALUE(0.00) };
+    simde_mm512_storeu_ph(r, a);
+    simde_assert_equal_vf16(sizeof(r) / sizeof(r[0]), r, test_vec[i].r, 1);
+  }
+
+  return 0;
+#else
+  fputc('\n', stdout);
+  for (int i = 0 ; i < 8 ; i++) {
+    simde__m512h a = simde_test_x86_random_f16x32(SIMDE_FLOAT16_VALUE(-1000.0), SIMDE_FLOAT16_VALUE(1000.0));
+    simde_float16 r[sizeof(simde__m512) / sizeof(simde_float16)] = {0};
+    simde_mm512_storeu_ph(r, a);
+
+    simde_test_x86_write_f16x32(2, a, SIMDE_TEST_VEC_POS_FIRST);
+    simde_test_codegen_write_vf16(2, sizeof(r) / sizeof(r[0]), r, SIMDE_TEST_VEC_POS_LAST);
+  }
+  return 1;
+#endif
+}
+#endif
+
 static int
 test_simde_mm512_mask_storeu_ps (SIMDE_MUNIT_TEST_ARGS) {
 #if 1
@@ -661,6 +970,7 @@ test_simde_mm512_mask_storeu_ps (SIMDE_MUNIT_TEST_ARGS) {
   return 1;
 #endif
 }
+
 SIMDE_TEST_FUNC_LIST_BEGIN
   SIMDE_TEST_FUNC_LIST_ENTRY(mm256_storeu_epi8)
   SIMDE_TEST_FUNC_LIST_ENTRY(mm256_storeu_epi16)
@@ -668,8 +978,13 @@ SIMDE_TEST_FUNC_LIST_BEGIN
   SIMDE_TEST_FUNC_LIST_ENTRY(mm256_storeu_epi32)
   SIMDE_TEST_FUNC_LIST_ENTRY(mm256_storeu_epi64)
   SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_storeu_epi16)
+  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_storeu_epi32)
+  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_storeu_epi64)
   SIMDE_TEST_FUNC_LIST_ENTRY(mm512_storeu_ps)
   SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_storeu_ps)
+  #if defined(SIMDE_FLOAT16_IS_SCALAR)
+    SIMDE_TEST_FUNC_LIST_ENTRY(mm512_storeu_ph)
+  #endif
 SIMDE_TEST_FUNC_LIST_END
 
 #include <test/x86/avx512/test-avx512-footer.h>
